stm32-metapac

Crates

git

Versions

stm32wba54ce

Flavors

Ioretenr

Struct Ioretenr 

#[repr(transparent)]
pub struct Ioretenr(pub u32);
port A Standby IO retention enable register

Tuple Fields

0: u32

Implementations



impl Ioretenr

pub const fn en(&self, n: usize) -> bool

Port A Standby GPIO retention enable Access can be protected by GPIOA SECy, privilege protection is controlled by SPRIV or NSPRIV. When set, each bit enables the Standby GPIO retention feature for PAy

pub const fn set_en(&mut self, n: usize, val: bool)

Port A Standby GPIO retention enable Access can be protected by GPIOA SECy, privilege protection is controlled by SPRIV or NSPRIV. When set, each bit enables the Standby GPIO retention feature for PAy